@@ -29,70 +29,41 @@
 
 #include "tracker-results-window.h"
 #include "tracker-aligned-window.h"
-#include "tracker-utils.h"
+#include "tracker-regex.h"
 
 #define MAX_ITEMS 10
 
-#define MUSIC_QUERY	  \
-	"SELECT" \
-	"  ?uri ?title ?tooltip ?uri fts:rank(?urn) " \
+#define FILE_SEARCH_QUERY(rdftype) \
+	"SELECT DISTINCT" \
+	"  ?uri ?title ?tooltip ?uri '' " \
 	"WHERE {" \
-	"  ?urn a nfo:Audio ;" \
-	"  nie:url ?uri ; " \
-	"  nfo:fileName ?title ;" \
-	"  nfo:belongsToContainer ?tooltip ." \
-	"  ?urn fts:match \"%s*\" " \
+	"  { " \
+	"    { " \
+	"      ?urn a " #rdftype "; " \
+	"	 nie:isStoredAs ?file . " \
+	"      ?file nie:url ?uri ; " \
+	"	 nfo:belongsToContainer ?tooltip ; " \
+	"	 nfo:fileName ?title . " \
+	"    } UNION { " \
+	"      ?urn a nfo:FileDataObject ; " \
+	"	 nie:url ?uri ; " \
+	"	 nfo:belongsToContainer ?tooltip ; " \
+	"	 nfo:fileName ?title . " \
+	"      ?content a " #rdftype "; " \
+	"	 nie:isStoredAs ?urn . " \
+	"    } " \
+	"  } " \
+	"  ?urn fts:match \"%s*\" . " \
 	"}" \
 	"ORDER BY DESC(fts:rank(?urn)) " \
 	"OFFSET 0 LIMIT %d"
-#define IMAGE_QUERY	  \
-	"SELECT" \
-	"  ?uri ?title ?tooltip ?uri fts:rank(?urn) " \
-	"WHERE {" \
-	"  ?urn a nfo:Image ;" \
-	"  nie:url ?uri ; " \
-	"  nfo:fileName ?title ;" \
-	"  nfo:belongsToContainer ?tooltip ." \
-	"  ?urn fts:match \"%s*\" " \
-	"} " \
-	"ORDER BY DESC(fts:rank(?urn)) " \
-	"OFFSET 0 LIMIT %d"
-#define VIDEO_QUERY	  \
-	"SELECT" \
-	"  ?uri ?title ?tooltip ?uri fts:rank(?urn) " \
-	"WHERE {" \
-	"  ?urn a nmm:Video ;" \
-	"  nie:url ?uri ; " \
-	"  nfo:fileName ?title ;" \
-	"  nfo:belongsToContainer ?tooltip ." \
-	"  ?urn fts:match \"%s*\" " \
-	"} " \
-	"ORDER BY DESC(fts:rank(?urn)) " \
-	"OFFSET 0 LIMIT %d"
-#define DOCUMENT_QUERY	  \
-	"SELECT" \
-	"  ?uri ?title ?tooltip ?uri fts:rank(?urn) " \
-	"WHERE {" \
-	"  ?urn a nfo:Document ;" \
-	"  nie:url ?uri ; " \
-	"  nfo:fileName ?title ;" \
-	"  nfo:belongsToContainer ?tooltip ." \
-	"  ?urn fts:match \"%s*\" " \
-	"} " \
-	"ORDER BY DESC(fts:rank(?urn)) " \
-	"OFFSET 0 LIMIT %d"
-#define FOLDER_QUERY	  \
-	"SELECT" \
-	"  ?uri ?title ?tooltip ?uri fts:rank(?urn) " \
-	"WHERE {" \
-	"  ?urn a nfo:Folder ;" \
-	"  nie:url ?uri ; " \
-	"  nfo:fileName ?title ;" \
-	"  nfo:belongsToContainer ?tooltip ." \
-	"  ?urn fts:match \"%s*\" " \
-	"} " \
-	"ORDER BY DESC(fts:rank(?urn)) " \
-	"OFFSET 0 LIMIT %d"
+
+#define MUSIC_QUERY FILE_SEARCH_QUERY(nfo:Audio)
+#define IMAGE_QUERY FILE_SEARCH_QUERY(nfo:Image)
+#define VIDEO_QUERY FILE_SEARCH_QUERY(nmm:Video)
+#define DOCUMENT_QUERY FILE_SEARCH_QUERY (nfo:Document)
+#define FOLDER_QUERY FILE_SEARCH_QUERY (nfo:Folder)
+
 #define APP_QUERY	  \
 	"SELECT" \
 	"  ?urn ?title ?tooltip ?link fts:rank(?urn) nfo:softwareIcon(?urn)" \
@@ -388,7 +359,16 @@ tracker_results_window_init (TrackerResultsWindow *self)
 	GError *error = NULL;
 
 	self->cancellable = g_cancellable_new ();
+
+#ifdef HAVE_TRACKER3
+	self->connection = tracker_sparql_connection_bus_new ("org.freedesktop.Tracker3.Miner.Files",
+	                                                      NULL,
+	                                                      NULL,
+	                                                      &error);
+#else
 	self->connection = tracker_sparql_connection_get (self->cancellable, &error);
+#endif
+
 	if (error != NULL) {
 		g_warning ("Cannot connect to tracker: %s\n", error->message);
 		g_error_free (error);
@@ -407,7 +387,7 @@ tracker_results_window_init (TrackerResultsWindow *self)
 	gtk_widget_show (vbox);
 
 	self->scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-	gtk_container_add (GTK_CONTAINER (vbox), self->scrolled_window);
+	gtk_box_pack_start (GTK_BOX (vbox), self->scrolled_window, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (self->scrolled_window),
 	                                GTK_POLICY_AUTOMATIC,
 	                                GTK_POLICY_AUTOMATIC);
@@ -420,7 +400,7 @@ tracker_results_window_init (TrackerResultsWindow *self)
 
 	self->label = gtk_label_new (NULL);
 	gtk_widget_set_sensitive (self->label, FALSE);
-	gtk_container_add (GTK_CONTAINER (vbox), self->label);
+	gtk_box_pack_start (GTK_BOX (vbox), self->label, TRUE, TRUE, 0);
 
 	self->icon_theme = gtk_icon_theme_get_default ();
 
@@ -646,7 +626,7 @@ item_data_new (const gchar     *urn,
 {
 	ItemData *id;
 
-	id = g_slice_new0 (ItemData);
+	id = g_new0 (ItemData, 1);
 
 	id->urn = g_strdup (urn);
 	id->title = g_strdup (title);
@@ -667,7 +647,7 @@ item_data_free (ItemData *id)
 	g_free (id->link);
 	g_free (id->icon_name);
 
-	g_slice_free (ItemData, id);
+	g_free (id);
 }
 
 static SearchQuery *
@@ -677,7 +657,7 @@ search_query_new (gint                  request_id,
 {
 	SearchQuery *sq;
 
-	sq = g_slice_new0 (SearchQuery);
+	sq = g_new0 (SearchQuery, 1);
 
 	sq->request_id = request_id;
 	sq->cancellable = g_cancellable_new ();
@@ -697,7 +677,7 @@ search_query_free (SearchQuery *sq)
 	}
 
 	g_slist_free_full (sq->results, (GDestroyNotify) item_data_free);
-	g_slice_free (SearchQuery, sq);
+	g_free (sq);
 }
 
 static gchar *
